pub struct Field<'a> {
pub name: String,
pub raw_name: &'a str,
pub value: String,
pub cst_node: NodeId,
}Expand description
A field that was not specifically parsed into a typed representation.
Fields
name: StringThe canonicalized field name.
raw_name: &'a strThe raw field name as written in the source.
value: StringThe field value (first line only; continuation lines are concatenated with newlines).
cst_node: NodeIdBack-reference to the CST field node.