Parser that builds a CST from source text.
Hand-written recursive descent parser for .cabal files.
Transforms the token stream from the lexer into a CST. The parser uses indentation levels to determine nesting — sections contain fields that are indented more than the section header, fields contain continuation lines indented more than the field name, etc.
Structs
- Parse
Result - The result of parsing a
.cabalfile.
Functions
- parse
- Parse a
.cabalsource string into a CST with diagnostics.